/**
 * Test case for create.
 * Runs with mocha.
 */
'use strict'

const create = require('../lib/create.js')
const co = require('co')
const apemanport = require('apemanport')
const assert = require('assert')
const apemanApp = require('apeman-app')
const request = require('request')

describe('create', () => {
  let server, port
  before(() => co(function * () {
    let app = create({})
    assert.ok(app)
    port = yield apemanport.find()
    server = yield apemanApp('testing-app', {
      configuration: {
        $apps: {
          'testing-app': {
            '/': [
              app,
              (req, res) => {
                res.json({
                  success: true
                })
              }
            ]
          }
        }
      },
      port: port
    })
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Create an app.', (done) => {
    request(`http://localhost:${port}/`, (err, res, body) => {
      assert.ifError(err)
      assert.equal(res.statusCode, 200)
      let data
      assert.doesNotThrow(() => {
        data = JSON.parse(body)
      })
      assert.ok(data)
      assert.ok(data.success)
      done()
    })
  })
})

/* global describe, it before, after */
